@@ -75,7 +75,7 @@ MODULE_ENTRY (fill_info) (GdkPixbufFormat *info)
 
   info->name        = "gif";
   info->signature   = (GdkPixbufModulePattern *) signature;
-  info->description = N_("The GIF image format");
+  info->description = NC_("image format", "GIF");
   info->mime_types  = (gchar **) mime_types;
   info->extensions  = (gchar **) extensions;
   info->flags       = GDK_PIXBUF_FORMAT_WRITABLE | GDK_PIXBUF_FORMAT_THREADSAFE;
