@@ -54,7 +54,7 @@ MODULE_ENTRY (fill_info) (GdkPixbufFormat *info)
 
   info->name        = "ico";
   info->signature   = (GdkPixbufModulePattern *) signature;
-  info->description = N_("The ICO image format");
+  info->description = NC_("image format", "Windows icon");
   info->mime_types  = (gchar **) mime_types;
   info->extensions  = (gchar **) extensions;
   info->flags       = GDK_PIXBUF_FORMAT_THREADSAFE;
