@@ -131,7 +131,7 @@ MODULE_ENTRY (fill_info) (GdkPixbufFormat *info)
 
   info->name        = "jpeg";
   info->signature   = (GdkPixbufModulePattern *) signature;
-  info->description = N_("The JPEG image format");
+  info->description = NC_("image format", "JPEG");
   info->mime_types  = (gchar **) mime_types;
   info->extensions  = (gchar **) extensions;
   info->flags       = GDK_PIXBUF_FORMAT_WRITABLE | GDK_PIXBUF_FORMAT_THREADSAFE;
