@@ -53,7 +53,7 @@ MODULE_ENTRY (fill_info) (GdkPixbufFormat *info)
 
   info->name        = "wmf";
   info->signature   = (GdkPixbufModulePattern *) signature;
-  info->description = N_("The WMF image format");
+  info->description = NC_("image format", "WMF");
   info->mime_types  = (gchar **) mime_types;
   info->extensions  = (gchar **) extensions;
   info->flags       = GDK_PIXBUF_FORMAT_THREADSAFE;
