@@ -997,7 +997,7 @@ MODULE_ENTRY (fill_info) (GdkPixbufFormat *info)
 
 	info->name = "tga";
 	info->signature = (GdkPixbufModulePattern *) signature;
-	info->description = N_("The Targa image format");
+	info->description = NC_("image format", "Targa");
 	info->mime_types = (gchar **) mime_types;
 	info->extensions = (gchar **) extensions;
 	info->flags = GDK_PIXBUF_FORMAT_THREADSAFE;
